# Supplementary Material

# Estimating SNPs-protein levels univariate associations

setwd("") # insert the path of your working directory

library(MASS)
library(parallel)
library(lme4qtl)

#Loading Data
load("dataset.RData")
# We keep only the 155 unaffected controls with genotype data
data<-data[which(data$MS==0 & !is.na(data$rs1815606)),]

# Sorting
data_ord<-data[order(data$SUBFAMID, data$IID, data$PAT, data$MAT),] # SUBFAMID=household id, ID=individual id, PAT = father id, MAT= mother id
rownames(data_ord)<-data_ord$IID


#kinship matrix
load("kinship_matrix.RData")
kmat<-kmat[as.character(data_ord$IID),as.character(data_ord$IID)]

#Creating Mother label to consider siblings shared environment effect
data_ord$MAT2<-data$MAT
data_ord$MAT2[which(data_ord$MAT!=0)]<- as.character(data_ord$MAT)[which(data_ord$MAT!=0)]
data_ord$MAT2[which(data_ord$MAT==0)]<- paste(as.character(data_ord$IID)[which(data_ord$MAT==0)], as.character(data_ord$SUBFAMID)[which(data_ord$MAT==0)], sep = "")

#Protein interest
name<-"GC_HPA001526"
#name<-"PLAT_HPA003412"
#name<-"ANXA1_HPA011271"
#name<-"SOD1_HPA001401"
#name<-"PTGER4_HPA012756"
#name<-"FADD_HPA001464"
#name<-"IRF8_HPA002531"

#Standardizing protein levels
data_ord[,as.character(name)]<-scale(data_ord[,as.character(name)])

#Taking SNPs names
snps<-names(data_ord[,64:20462])

#Function to calculate univariate SNP-Protein levels associations. n.cores >1 to make function run faster
pqtl<-function(data_ord,snps,nsnps,kmat, n.cores){
  pqtl_fun <- function(i,data_ord,snps,nsnps,kmat){
    
    namesnp<-snps[i]
    model <- as.formula(paste(name, " ~ (1|IID) + (1|MAT2) + SEX+", snps[i], collapse = " "))
    
    # Using Hardy-Weinberg to impute missing SNPs (very rare)
    p<-(sum(data_ord[,namesnp], na.rm=T)/(length(which(!is.na(data_ord[,namesnp])==TRUE))*2))
    data_ord[is.na(data_ord[,namesnp]), namesnp] <- sample(c(0, 1, 2), size = 1, replace = TRUE, prob = c((1-p)^2, (p*(1-p)), p^2))
    
    m1 <- relmatLmer(model, data=data_ord,REML=F, relmat = list(IID = kmat))
    m1<-summary(m1)
    estimate<-m1$coefficients[3,1]
    se<-m1$coefficients[3,2]
    pval<-signif(1 - pchisq((m1$coefficients[3,1]/m1$coefficients[3,2])^2, 1), 7)
    LCL<-estimate - qnorm(0.975)*se
    UCL<-estimate + qnorm(0.975)*se
    dataframe <- as.data.frame(cbind(namesnp, estimate, se, LCL, UCL, pval))
    
  }
  
  data_fin <- suppressMessages(mclapply(1:nsnps,pqtl_fun,data_ord=data_ord,snps=snps,nsnps=nsnps,kmat=kmat,mc.cores=n.cores))
  
  final <- do.call(rbind,data_fin)
  
}

# Running the function and printing the output in an Excel file
nsnps<-20399
aaa<-pqtl(data_ord,snps,nsnps,kmat,100)
colnames(aaa) <- c("SNP", "Additive Effect", "SE", "95%LCL", "95%UCL", "p-value")
write.table(aaa, file="GC_HPA001526.csv", col.names=T, row.names=F, quote=F, sep=";")

